@@ -105,7 +105,7 @@ def bufferPrinter(bs: buffer):
 
 if __name__ == "__main__":
     ss = server()
-    l1 = ss.buildLine(top=1, pattern=[" Main Pattern : ", SR(background=240), "  ",Vstr("v:^15"),"  "], background=52, color=207)
+    l1 = ss.buildLine(top=1, pattern=[" Main Pattern : ", SR(background=240), "  ",Vstr("v"),"  "], background=52, color=207)
     l2 = ss.buildLine(top=2, pattern=[" Main Pattern  ", SR(background=240), Vint("count:>8")," ", SR(background=245), Vint("total:>8")," "], background=55, color=207)
     upperConsole = ss.buildBuffer(top=3, height=20)
     lowerConsole = ss.buildBuffer(bottom=2, top=25, background = 117)
